@@ -7,6 +7,12 @@
 #ifdef HAVE_STDLIB_H
 #  include <stdlib.h>
 #endif
+#if HAVE_STDBOOL_H
+# include <stdbool.h>
+#else
+typedef enum {false = 0, true = 1} bool;
+#endif
+
 #include "liba2ps.h"
 
 #define _(V) sprintf(buf, "%.4d",V),a2ps_print_string(job,buf, String)
