@@ -22,6 +22,14 @@ EOC
 
 print "\n";
 
+# List of the people who maintain the package
+title "Interim Maintainer";
+print <<'EOC';
+ * Masayuki Hatta <mhatta@gnu.org>
+EOC
+
+print "\n";
+
 # List of the people who helped the translation
 title "Translators";
 open (STDIN, $translator_file)
@@ -97,7 +105,9 @@ print <<'EOC';
  * Alexander Mai (OS/2 port) <mai@migdal.ikp.physik.tu-darmstadt.de>
  * Ansgar Duelmer (DOS) <Ansgar.Duelmer@anorg.chemie.uni-giessen.de>
  * Chuck Robey (FreeBSD) <chuckr@mat.net>
- * Dirk Eddelbuettel (Debian) <edd@debian.org>
+ * Dirk Eddelbuettel (formerly Debian) <edd@debian.org>
+ * Masayuki Hatta (Debian) <mhatta@debian.org>
+ * Michael Williams (Mac OS X) <mike@dreamboatrecords.co.uk>
  * Paulo Matos (RPM) <pjsm@students.fct.unl.pt>
 EOC
 
