@@ -1,9 +1,9 @@
 /* basename.c -- return the last element in a path
-   Copyright (C) 1990, 1998 Free Software Foundation, Inc.
+   Copyright (C) 1990, 1998, 1999 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -23,22 +23,43 @@
 # define FILESYSTEM_PREFIX_LEN(Filename) 0
 #endif
 
+#ifndef PARAMS
+# if defined PROTOTYPES || (defined __STDC__ && __STDC__)
+#  define PARAMS(Args) Args
+# else
+#  define PARAMS(Args) ()
+# endif
+#endif
+
 #ifndef ISSLASH
 # define ISSLASH(C) ((C) == '/')
 #endif
 
+char *base_name PARAMS ((char const *name));
+
 /* In general, we can't use the builtin `basename' function if available,
    since it has different meanings in different environments.
-   In some environments the builtin `basename' modifies its argument.  */
+   In some environments the builtin `basename' modifies its argument.
+   If NAME is all slashes, be sure to return `/'.  */
 
 char *
 base_name (char const *name)
 {
   char const *base = name += FILESYSTEM_PREFIX_LEN (name);
+  int all_slashes = 1;
+  char const *p;
 
-  for (; *name; name++)
-    if (ISSLASH (*name))
-      base = name + 1;
+  for (p = name; *p; p++)
+    {
+      if (ISSLASH (*p))
+	base = p + 1;
+      else
+	all_slashes = 0;
+    }
+
+  /* If NAME is all slashes, arrange to return `/'.  */
+  if (*base == '\0' && ISSLASH (*name) && all_slashes)
+    --base;
 
   return (char *) base;
 }
