@@ -2,7 +2,7 @@
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -17,8 +17,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #ifndef _GETSHLINE_H_
 # define _GETSHLINE_H_ 1
 
-# include <stdio.h>
-
 /* Support of prototyping when possible */
 # ifndef PARAMS
 #   if PROTOTYPES
@@ -28,7 +26,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #   endif /* no PROTOTYPES */
 # endif
 
-/* These routines are devoted to reading meaning full lines.  By 
+/* These routines are devoted to reading meaning full lines.  By
  * meaningful is ment, not empty, and not behind a COMMENTOR symbol.
  * These lines are ended by a DELIMITER, but may be continued if
  * DELIMITER is preceded by a DELIMITER_QUOTE.
@@ -38,7 +36,9 @@ int
 getshline PARAMS ((char **_lineptr, size_t *_n, FILE *_stream));
 
 int
-getshdelim PARAMS ((char **_lineptr, size_t *_n, int _delimiter, int _delimiter_quote, int _commentor, FILE *_stream));
+getshdelim PARAMS ((char **_lineptr, size_t *_n,
+		    int _delimiter, int _delimiter_quote, int _commentor,
+		    FILE *_stream));
 
 
 /* These routines are the pending of the above routines, keeping
@@ -51,9 +51,14 @@ getshdelim PARAMS ((char **_lineptr, size_t *_n, int _delimiter, int _delimiter_
 
 /* A basic example is available at the bottom of getshline.c */
 int
-getshline_numbered PARAMS ((int *_firstline, int *_lastline, char **_lineptr, size_t *_n, FILE *_stream));
+getshline_numbered PARAMS ((int *_firstline, int *_lastline,
+			    char **_lineptr, size_t *_n,
+			    FILE *_stream));
 
 int
-getshdelim_numbered PARAMS ((int *_firstline, int *_lastline, char **_lineptr, size_t *_n, int _delimiter, int _delimiter_quote, int _commentor, FILE *_stream));
+getshdelim_numbered PARAMS ((int *_firstline, int *_lastline,
+			     char **_lineptr, size_t *_n,
+			     int _delimiter, int _delimiter_quote,
+			     int _commentor, FILE *_stream));
 
 #endif /* not defined(_GETSHLINE_H_) */
