@@ -3,7 +3,7 @@
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -34,8 +34,7 @@
    return nonzero, else 0.  */
 
 int
-isdir (path)
-     char *path;
+isdir (const char *path)
 {
   struct stat stats;
 
