@@ -3,7 +3,7 @@
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -58,11 +58,11 @@
 # include <inttypes.h>
 #endif
 
-#if !HAVE_DECL_FPUTS
+#if NEED_FPUTS_DECL
 extern void fputs ();
 #endif
 
-#if !HAVE_DECL_STRLEN
+#if NEED_STRLEN_DECL
 extern int strlen ();
 #endif
 
