@@ -10,7 +10,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -420,22 +420,16 @@ typedef enum {false = 0, true = 1} bool;
 | Take care of NLS matters.  |
 `---------------------------*/
 
-#if HAVE_LOCALE_H
+#ifdef HAVE_LOCALE_H
 # include <locale.h>
 #endif
-#if !HAVE_SETLOCALE
-# define setlocale(Category, Locale) /* empty */
+#ifndef HAVE_SETLOCALE
+# define setlocale(Category, Locale)
 #endif
 
-#if ENABLE_NLS
-# include <libintl.h>
-# define _(Text) gettext (Text)
-#else
-# define bindtextdomain(Domain, Directory) /* empty */
-# define textdomain(Domain) /* empty */
-# define _(Text) Text
-#endif
-#define N_(Text) Text
+#include "gettext.h"
+#define _(Msgid)  gettext (Msgid)
+#define N_(Msgid) (Msgid)
 
 
 /*----------.
