@@ -3,6 +3,7 @@
  *
  * Copyright (c) 1988-1993 Miguel Santana
  * Copyright (c) 1995-2000 Akim Demaille, Miguel Santana
+ * Copyright (c) 2007 Akim Demaille, Miguel Santana and Masayuki Hatta
  */
 
 /*
@@ -10,7 +11,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -56,6 +57,7 @@
 #include "signame.h"
 #include "long-options.h"
 #include "version-etc.h"
+#include <locale.h>
 
 /* From basename.c */
 char *base_name PARAMS ((const char *path));
@@ -651,7 +653,8 @@ usage (int status)
   fprintf (stream, _("\
 Usage: %s [OPTION]... [FILE]...\n\
 \n\
-Convert FILE(s) or standard input to PostScript.\n\
+Convert FILE(s) or standard input to PostScript.  By default, the output\n\
+is sent to the default printer.  An output file may be specified with -o.\n\
 \n\
 Mandatory arguments to long options are mandatory for short options too.\n\
 Long options marked with * require a yes/no argument, corresponding\n\
@@ -776,7 +779,8 @@ PostScript, PDF etc.\n"));
   --version-control=WORD     override the usual version control\n\
   --suffix=SUFFIX            override the usual backup suffix\n\
   -P, --printer=NAME         send output to printer NAME\n\
-  -d                         send output to the default printer\n"));
+  -d                         send output to the default printer\n\
+                             (this is the default behavior)\n"));
 
   sputc ('\n');
   sfputs (_("PostScript:\n"));
@@ -816,7 +820,7 @@ To print as a booklet on the default printer, which is Duplex capable,\n\
   /* Finally, some addresses. */
   sputc ('\n');
   sfputs (_("\
-News, updates and documentation: visit http://www.inf.enst.fr/~demaille/a2ps/.\n"));
+News, updates and documentation: visit http://www.gnu.org/software/a2ps/.\n"));
   sfputs (_("Report bugs to <bug-a2ps@gnu.org>.\n"));
 
   exit (status);
@@ -937,7 +941,8 @@ main (int argc, char *argv[])
   program_invocation_name = xstrdup (program_name);
   version_etc_copyright = N_("\
 Copyright (c) 1988-1993 Miguel Santana\n\
-Copyright (c) 1995-2000 Akim Demaille, Miguel Santana");
+Copyright (c) 1995-2000 Akim Demaille, Miguel Santana\n\
+Copyright (c) 2007- Akim Demaille, Miguel Santana and Masayuki Hatta");
 
   /* Set the NLS on */
   setlocale (LC_TIME, "");
@@ -1176,10 +1181,23 @@ Copyright (c) 1995-2000 Akim Demaille, Miguel Santana");
 	     * in is this one!
 	     * To this end, we need to put more information in file_job
 	     * on how its processing went. */
+	    
+	    struct file_job * file_job;
+	    size_t len;
+	    
+	    /* 'delegation_tmpname' is necessary not null else it is a
+	       failed job and we ignore it */
+	    file_job = CURRENT_FILE (job);
+	    len = job->jobs->len;
+	    while (!file_job->delegation_tmpname)
+	      {
+		len--;
+		file_job = job->jobs->content[len - 1];
+	      }
+	    
 	    a2ps_open_output_stream (job);
-	    pslex_dump (job->output_stream->fp,
-			CURRENT_FILE (job)->delegation_tmpname);
-	    unlink (CURRENT_FILE (job)->delegation_tmpname);
+	    pslex_dump (job->output_stream->fp, file_job->delegation_tmpname);
+	    unlink (file_job->delegation_tmpname);
 	    a2ps_close_output_stream (job);
 	    msg_job_pages_printed (job);
 	  }
